@@ -663,11 +663,50 @@ def dep_matcher(doc): #[('svx', [1, 0, 2])]
 	return [(spacy.nlp.vocab[name].text, ar) for name, ar in dep_matcher.matcher(doc)] 
 	#for name, ar in depmatchers['svx'](doc) : print(doc[ar[1]], doc[ar[0]], doc[ar[2]])
 
-[setattr(builtins, k, v) for k, v in globals().items() if not k.startswith("_") and not '.' in k and not hasattr(builtins,k) ] #setattr(builtins, "spacy", spacy)			
+es_toks = lambda sid, doc:  [ {'_id': f"{sid}-tok-{t.i}", '_source': {"type":"tok", "src":sid, 'i':t.i, "head":t.head.i, 'lex':t.text, 'lem':t.lemma_, 'pos':t.pos_, 'tag':t.tag_, 'dep':t.dep_, "gpos":t.head.pos_, "glem":t.head.lemma_ } } for t in doc ] 
+def es_postag(doc): 
+	from dic.oneself import oneself 
+	return "_^ " + ' '.join([ f"_{t.pos_}_{t.tag_}" if t.pos_ in ('PROPN','NUM','X','SPACE') else f"{t.text if t.text in ('I') else t.text.lower()}_{t.lemma_}_{t.pos_}_{t.tag_}{oneself.get(t.text.lower(), '')}"  for t in doc]) # uniq by ana #,'PUNCT'
+
+def kps(doc): 
+	''' doc is of single sent, 2022.9.8 '''
+	_kps = []
+	[ _kps.append(f"{t.pos_}:{t.lemma_}") for t in doc]  # VERB:book
+	[ _kps.append(f"_{t.lemma_}:{t.text.lower()}") for t in doc]  # _book:booked,  added 2022.8.21
+	[ _kps.append(f"{t.tag_}:{t.pos_}_{t.lemma_}") for t in doc]  # VBD:VERB_book,  added 2022.8.25
+	[ _kps.append(f"{t.dep_}:{t.head.pos_}_{t.head.lemma_}:{t.pos_}_{t.lemma_}") for t in doc if t.pos_ not in ('PUNCT')]  # 
+	[ _kps.append(f"~{t.dep_}:{t.pos_}_{t.lemma_}:{t.head.pos_}_{t.head.lemma_}") for t in doc if t.pos_ not in ('PUNCT')]  # 
+	[ _kps.append(f"NP:{doc[sp.end-1].pos_}_{doc[sp.end-1].lemma_}:{sp.text.lower()}") for sp in doc.noun_chunks ]
+	_kps.append( f"stype:" +  "simple_snt" if simple_sent(doc) else "complex_snt" )
+	if compound_snt(doc) : _kps.append("stype:compound_snt")
+
+	# [('pp', 'on the brink', 2, 5), ('ap', 'very happy', 9, 11)]
+	for lem, pos, type, chunk in kp_matcher(doc): #brink:NOUN:pp:on the brink
+		_kps.append(f"{type}:{pos}_{lem}:{chunk}")
+	for trpx, row in dep_matcher(doc): #[('svx', [1, 0, 2])] ## consider:VERB:vnpn:**** 
+		verbi = row[0] #consider:VERB:be_vbn_p:be considered as
+		_kps.append(f"{trpx}:{doc[verbi].pos_}_{doc[verbi].lemma_}")
+		if trpx == 'sva' and doc[row[0]].lemma_ == 'be': # fate is sealed, added 2022.7.25   keep sth. stuck
+			_kps.append(f"sbea:{doc[row[1]].pos_}_{doc[row[1]].lemma_}:{doc[row[2]].pos_}_{doc[row[2]].lemma_}")
+		
+	# last to be called, since NP is merged
+	for row in verbnet_matcher(doc): #[(1, 0, 3, 'NP V S_ING')]
+		if len(row) == 4: 
+			verbi, ibeg, iend, chunk = row
+			if doc[verbi].lemma_.isalpha() : 
+				_kps.append(f"verbnet:{doc[verbi].pos_}_{doc[verbi].lemma_}:{chunk}")
+
+	for name,ibeg,iend in post_np_matcher(doc): #added 2022.7.25
+		if name in ('v_n_vbn','v_n_adj'): 
+			_kps.append(f"{name}:{doc[ibeg].pos_}_{doc[ibeg].lemma_}:{doc[ibeg].lemma_} {doc[ibeg+1].lemma_} {doc[ibeg+2].text}")
+	return _kps
+
+[setattr(builtins, k, v) for k, v in globals().items() if not k.startswith("_") and not '.' in k and not hasattr(builtins,k) ] #setattr(builtins, "spacy", spacy)
 if __name__	== '__main__': 
 	doc = spacy.nlp("It is on the brink, and I am very happy, and I leave these books opened.") 
-	merge_np(doc)
-	print ( post_np_matcher(doc) ) 
+	print (es_postag(doc), kps(doc)) 
+	#merge_np(doc)
+	#print ( post_np_matcher(doc) ) 
 	#print (parse("I love you."))
 	#print(sntbr("[\u8bd1\u6587]The 55-kilometre Hong Kong Zhuhai-Macau Bridge is an extraordinary engineering. It is the world's longest sea-crossing transportation system combining bridges and tunnels, which joins the three cities of Hong Kong Zhuhai and Macao, cutting the travelling time among them from 3 hours to 30 minutes. The reinforced concrete bridge with huge spans fully not only proves that China has the ability to complete the record-breaking mega-construction, but also will enhance the regional integration and boost the economic growth. It plays a crucial role in the overall plan to develop China’s Great Bay Area, which China intends to turn into one rivaling those of San Francisco, New York and Tokyo in terms of technological innovation and economic prosperity.", with_pid=True))
 #c:\users\zhang\appdata\local\programs\python\python38\lib\site-packages  
