@@ -87,7 +87,7 @@ config = {
 			 "@timestamp":{"format":"strict_date_optional_time||epoch_millis", "type":"date"},
 			"errs": { "type": "text", "analyzer": "path_ana" ,"fielddata":"true" },
 			"feedback": { "type": "text", "analyzer": "feedback_ana" ,"fielddata":"true" },
-			"kps": { "type": "text", "analyzer": "path_ana3"  },
+			"kps": { "type": "text", "analyzer": "path_ana3" ,"fielddata":"true" },
 			"pterm": { "type": "text", "analyzer": "path_ana"  }, # path term
 			"postag": { "type": "text", "analyzer": "postag_ana"},
 			"skenp": { "type": "text", "analyzer": "postag_ana"},
@@ -150,6 +150,7 @@ config = {
 			"stroke": { "type": "keyword", "index": "false"},
 			"strokes": { "type": "keyword", "index": "false"},
 			"text": { "type": "keyword", "index": "false"},
+			"doc_txt": { "type": "keyword", "index": "false"}, # spider 
 			"essay_or_snts": { "type": "keyword", "index": "false"},
 			"labels": { "type": "keyword"}, # for annotation 
 			"_snt": { "type": "keyword", "index": "false"},
