@@ -22,6 +22,17 @@ def likelihood(a,b,c,d, minus=None):  #from: http://ucrel.lancs.ac.uk/llwizard.h
 		print ("likelihood ex:",e, a,b,c,d)
 		return 0
 
+def  si_to_es(si, index, batch=10000, eshost='127.0.0.1',esport=9200): 
+	''' ie: spellerr, added 2022.9.6 '''
+	print (len(si), index,  flush=True) 
+	actions=[]
+	for s,i in si.items() if isinstance(si, dict) else si: 
+		try:
+			requests.post(f"http://{eshost}:{esport}/{index}/{s}", json={"s": s, "i":i})
+		except Exception as e:
+			print("ex:", e)	
+	print(">>load finished:" , index )
+
 def xblpop(r, name, arr, timeout=10, suc_prefix='suc:', err_prefix="err:"):
 	''' name:xsnt/xsnts, arr: {"snt": "hello"}  added 2022.4.4 '''
 	id  = r.xadd(name, arr)
@@ -83,4 +94,23 @@ def traverse(t, label='NP', f = lambda t:  print(t.pos()) ):
 if __name__ == '__main__': 
 	pass 
 	#logger = getlog()
-	#print (logger) 
\ No newline at end of file
+	#print (logger) 
+
+'''
+def  si_to_es(si, index, batch=10000, eshost='127.0.0.1',esport=9200): 
+	from elasticsearch import Elasticsearch,helpers
+	es = Elasticsearch([ f"http://{eshost}:{esport}" ])  
+	print (index, es, flush=True) 
+	actions=[]
+	for s,i in si.items() if isinstance(si, dict) else si: 
+		try:
+			actions.append( {'_op_type':'index', '_index':index, "_id": s, "_source":{"s": s, "i":i} })
+			if len(actions) >= batch: 
+				helpers.bulk(client=es,actions=actions, raise_on_error=False)
+				print ( actions[-1], flush=True)
+				actions = []
+		except Exception as e:
+			print("ex:", e)	
+	if actions : helpers.bulk(client=es,actions=actions, raise_on_error=False)
+	print(">>load finished:" , index )
+'''
\ No newline at end of file
