@@ -181,9 +181,39 @@ def dsk_fds(essay_or_snts:str="She has ready. It are ok.", timeout:int=5, gechos
 def dsk_mkf(essay_or_snts:str="She has ready. It are ok.", timeout:int=5, gechost:str='gpu120.wrask.com:8180' , dskhost:str='gpu120.wrask.com:7095'): 
 	return dsk_wrapper(essay_or_snts, asdsk=False, timeout=timeout, gechost=gechost, dskhost=dskhost)
 
-if __name__ == '__main__': 
-	print ( dsk_docjson(), flush=True) 
-	uvicorn.run(app, host='0.0.0.0', port=80)
+@app.post('/dsk/xessay', tags=["dsk"])
+def dsk_xessay(arr:dict={"essay_or_snts":"She has ready. It are ok."}, dskhost:str='172.17.0.1:7095'): 
+	''' to be filled into redis, 2022.9.6 '''
+	rid,tid,uid	= arr.get('rid', '0'), arr.get('tid', '0'), arr.get('uid', '0')
+	tdoc = spacy.nlp( arr.get('essay_or_snts','') )
+	dsk = get_dsk(arr['essay_or_snts'], dskhost=dskhost) 
+	arr['score'] = round(float(dsk.get('info',{}).get("final_score",0)),2)
+	arr['snts']  = [mkf.get('meta',{}).get('snt','') for mkf in dsk.get('snt',[])]
+	arr['info']  = dsk.get('info',{})
+	arr['doc']   = dsk.get('doc',{})
+	arr['kw']   = dsk.get('kw',{})
+	for t in tdoc:
+		arr[f'toks-{t.i}'] =  {'i':t.i, "head":t.head.i, 'lex':t.text, 'lem':t.lemma_, 'pos':t.pos_, 'tag':t.tag_, 'dep':t.dep_, "gpos":t.head.pos_, "glem":t.head.lemma_}
+
+	sntdic = {}
+	for i, mkf in enumerate(dsk.get('snt',[])):  
+		snt		= mkf.get('meta',{}).get('snt','')
+		sntkey	= f'snt:rid-{rid}:tid-{tid}:uid-{uid}:"{snt}"'
+		if not snt or r.hexists(sntkey, "meta"): continue
+		doc		= spacy.nlp(snt) 
+		cates = [ v['cate'][2:] for k,v in mkf.get('feedback',{}).items() if v['cate'].startswith("e_") or v['cate'].startswith("w_") ]
+		sntdic[sntkey] = { 'meta': mkf.get('meta',{}),"cates": cates,
+				"feedback": [ {'cate': v.get('cate',''), 'msg':v.get('short_msg',''), 'ibeg':v.get('ibeg',0)} for k,v in mkf.get('feedback',{}).items() if v['cate'].startswith("e_") or v['cate'].startswith("w_") ] ,
+				#"toks": [{'i':t.i, "head":t.head.i, 'lex':t.text, 'lem':t.lemma_, 'pos':t.pos_, 'tag':t.tag_, 'dep':t.dep_, "gpos":t.head.pos_, "glem":t.head.lemma_} for t in doc ],
+				"chunks": [ {"start":sp.start, "end": sp.end,"type":"NP", "lem": doc[sp.end-1].lemma_, "text":sp.text} for sp in doc.noun_chunks ],
+				} 
+		for t in doc:
+			sntdic[sntkey][f'toks-{t.i}'] =  {'i':t.i, "head":t.head.i, 'lex':t.text, 'lem':t.lemma_, 'pos':t.pos_, 'tag':t.tag_, 'dep':t.dep_, "gpos":t.head.pos_, "glem":t.head.lemma_}
+	
+	return {"hdoc": arr, "hsnts": sntdic} 
+
+if __name__ == '__main__':  #uvicorn.run(app, host='0.0.0.0', port=80)
+	print ( dsk_xessay(), flush=True) 
 	#print (dsk_wrapper("[\u8bd1\u6587]The 55-kilometre Hong Kong Zhuhai-Macau Bridge is an extraordinary engineering. It is the world's longest sea-crossing transportation system combining bridges and tunnels, which joins the three cities of Hong Kong Zhuhai and Macao, cutting the travelling time among them from 3 hours to 30 minutes. The reinforced concrete bridge with huge spans fully not only proves that China has the ability to complete the record-breaking mega-construction, but also will enhance the regional integration and boost the economic growth. It plays a crucial role in the overall plan to develop China’s Great Bay Area, which China intends to turn into one rivaling those of San Francisco, New York and Tokyo in terms of technological innovation and economic prosperity.", JSONEachRow=True))
 	#print (sntbr("[\u8bd1\u6587]The 55-kilometre Hong Kong Zhuhai-Macau Bridge is an extraordinary engineering. It is the world's longest sea-crossing transportation system combining bridges and tunnels, which joins the three cities of Hong Kong Zhuhai and Macao, cutting the travelling time among them from 3 hours to 30 minutes. The reinforced concrete bridge with huge spans fully not only proves that China has the ability to complete the record-breaking mega-construction, but also will enhance the regional integration and boost the economic growth. It plays a crucial role in the overall plan to develop China’s Great Bay Area, which China intends to turn into one rivaling those of San Francisco, New York and Tokyo in terms of technological innovation and economic prosperity."))
 
