@@ -290,7 +290,337 @@ def snt_kps(text:str="She has ready. It are ok. The justice delayed is justice d
 		id_source[f"{did}-{sid}"] = {'type':'snt', 'snt':snt.text.strip(), 'postag':postag,  'did':did, 'src': f"{did}-{sid}",  'tc': len(doc), 'kps': list(set(_kps)) }  
 	return id_source
 
+@app.get('/es/termsnts', tags=["es"], response_class=HTMLResponse)
+def es_termsnts(term:str="dobj:VERB_open:NOUN_door", cp:str='en',  term_name:str='kps',  snt_field:str='snt', hl_words:str="open,door", topk:int=10, sntsum:bool=True): 
+	''' return HTML <ol><li> , 2022.9.7 '''
+	from dic import lemma_lex
+	res		= requests.post(f"http://{requests.eshost}/{cp}/_search",json={"query": {"term": {term_name:term} }}).json() 
+	cnt		= res["hits"]["total"]["value"]
+	snts    = [ ar['_source'][snt_field] for ar in res["hits"]["hits"]]
+	words	= '|'.join([ '|'.join(list(lemma_lex.lemma_lex[w])) for w in hl_words.strip().split(',') if w in lemma_lex.lemma_lex])
+	arr		= [re.sub(rf'\b({words})\b', r'<font color="red">\g<0></font>', snt, flags=re.IGNORECASE) if words else snt for snt in snts]
+	html	= "\n".join([f"<li>{snt}</li>" for snt in arr])
+	return HTMLResponse(content=f"<ol> <b>{cnt}</b> Sentences {html}</ol>" if sntsum else f"<ol>{html}</ol>")
+
+@app.post('/es/dsk', tags=["es"])
+def es_dsk(dsk:dict={
+  "snt": [
+    {
+      "feedback": {
+        "_have _jj .@e_snt.miss.no_obj": {
+          "cate": "e_snt.miss.no_obj",
+          "iend": 5,
+          "kp": "_have _jj .",
+          "iend_byte": 14,
+          "by": "pigai_spss.kp_feedback_cn",
+          "word_list": "has ready .",
+          "ibeg": 2,
+          "ibeg_byte": 4,
+          "id": 1276467,
+          "short_msg": "搭配不当，建议将<b>have+形容词.</b>改为<a href=\"http://bbs.pigai.org/t27448-1-1.html\" target=\"_blank\"><b>have+形容词+名词.</b></a>。",
+          "kp_type": "HYB"
+        }
+      },
+      "meta": {
+        "pos_rewrite": "[^/^, She/PRP, has/VBZ, ready/JJ, ./.]",
+        "pred_lemma": "have",
+        "postag": "^_^_^ She_prp_prp_no_n_sb_she has_vbz_v_presten_have ready_jj_ready ._._.",
+        "snt": "She has ready.",
+        "lex_list": "She has ready .",
+        "pid": 0,
+        "tense": "",
+        "para_id": 0,
+        "sid": 0,
+        "tc": 4,
+        "sub_cnt": 1
+      }
+    },
+    {
+      "feedback": {
+        "ok/cap_err@e_cap.uc_expected": {
+          "cate": "e_cap.uc_expected",
+          "correct": "OK",
+          "kp": "ok/cap_err",
+          "iend_byte": 9,
+          "by": "caperr",
+          "word_list": "ok",
+          "ibeg": 3,
+          "ibeg_byte": 7,
+          "short_msg": "确认 <b>ok</b> 大小写使用正确。"
+        },
+        "_ok@i_spoken": {
+          "cate": "i_spoken",
+          "iend": 4,
+          "kp": "_ok",
+          "iend_byte": 9,
+          "by": "pigai_spss.kp_feedback_cn",
+          "word_list": "ok",
+          "ibeg": 3,
+          "ibeg_byte": 7,
+          "id": 1249604,
+          "short_msg": "<b>OK</b>是口语词汇，在书面写作中尽量不要使用。",
+          "kp_type": "HYB"
+        },
+        "_^ it are@e_snt.nv_agree": {
+          "cate": "e_snt.nv_agree",
+          "iend": 3,
+          "kp": "_^ it are",
+          "iend_byte": 6,
+          "by": "pigai_spss.kp_feedback_cn",
+          "word_list": "It are",
+          "ibeg": 1,
+          "ibeg_byte": 0,
+          "id": 1275611,
+          "short_msg": "主谓不一致，建议将<b>It are</b>改为<b>It is</b>。",
+          "kp_type": "HYB"
+        }
+      },
+      "meta": {
+        "pid": 0,
+        "para_id": 0,
+        "sid": 1,
+        "tc": 4,
+        "sub_cnt": 1,
+        "pos_rewrite": "[^/^, It/PRP, are/VBP, ok/JJ, ./.]",
+        "pred_lemma": "be",
+        "postag": "^_^_^ It_prp_n_it are_vbp_v_presten_be ok_jj_ok ._._.",
+        "snt": "It are ok.",
+        "lex_list": "It are ok .",
+        "vpat": [
+          "be _jj"
+        ],
+        "tense": ""
+      }
+    }
+  ],
+  "doc": {
+    "v_ttr": 1,
+    "x_len": 0,
+    "external_sim": 0,
+    "prmods_ratio": 0.25,
+    "pred_diff_avg": 2.4850001,
+    "b0": 0,
+    "mwe_pvd": 0.5,
+    "b1": 0.8333333,
+    "n_num": 0,
+    "d_ratio": 0,
+    "flesch_reading_ease": 0,
+    "b2": 0,
+    "b3": 0.16666667,
+    "score": 36.20861,
+    "b4": 0.16666667,
+    "sub_tc": 1,
+    "internal_sim": 0.30466038,
+    "simple_sent_ri": 0.59999996,
+    "d_len": 0,
+    "psmods_ratio": 0.5,
+    "gramv_vxp": 0,
+    "r_type": 2,
+    "h_ttr2": 0.5,
+    "gramv": 0,
+    "h_ttr1": 0.5,
+    "d_type": 0,
+    "incomplete_ratio": 0,
+    "lex_num": 8,
+    "prprn_type": 0,
+    "prmods_tc": 1,
+    "subcl_num": 0,
+    "gramv_vov": 0,
+    "a_num": 2,
+    "lemma_num": 8,
+    "snt_max": 4,
+    "token_num": 8,
+    "para_last_tratio": 0,
+    "lttr": 87.5,
+    "c_num": 0,
+    "p_ratio": 0,
+    "comma_ratio": 0,
+    "doc_tc": 8,
+    "p_type": 0,
+    "d_ttr": 0,
+    "word_diff_avg": 3.4528573,
+    "grammar_correct_ri": 0.990099,
+    "snt_min": 4,
+    "ast_sd": 0,
+    "word_type": 6,
+    "ttr1": 1.7320508,
+    "r_num": 2,
+    "grammar_err": 0.3,
+    "infcl_num": 0,
+    "n_type": 0,
+    "spell_err": 0,
+    "lex_type": 7,
+    "gramv_vxxp": 0,
+    "prmods_tc_new": 1,
+    "h_type": 1,
+    "h_len": 1,
+    "token_devia_ratio": 0,
+    "snt_correct_ratio": 0.57889825,
+    "prmods_ratio_new": 0.25,
+    "the_ratio": 0,
+    "para_first_tratio": 1,
+    "p_num": 0,
+    "a_ratio": 0.25,
+    "p_ttr2": 0,
+    "cate": 0,
+    "p_ttr1": 0,
+    "v_ttr2": 2,
+    "psmods_tc": 2,
+    "v_ttr1": 1,
+    "kp_err": 4,
+    "word_num": 6,
+    "v_len": 3,
+    "complex_max": 0,
+    "simple_sent_num": 2,
+    "a_ttr2": 2,
+    "score_kpu": 0,
+    "ast_new": 4,
+    "a_ttr1": 1,
+    "para_num": 1,
+    "snt_tc_30_39": 0,
+    "complex_factor": 0,
+    "h_ratio": 0.25,
+    "x_ttr": 0,
+    "d_ttr2": 0,
+    "d_ttr1": 0,
+    "snt_num": 2,
+    "kw_overlap": 0,
+    "cl_ratio": 0,
+    "mwe_pv": 1,
+    "snt_tc_40_": 0,
+    "prprtcl_num": 0,
+    "kp_correct_ri": 0.9259259,
+    "asl": 12,
+    "cl_sum": 0,
+    "h_ttr": 0.5,
+    "awl_sd": 1.0954452,
+    "word_gt7": 0,
+    "b3_b1": 0.20948619,
+    "word_gt6": 0,
+    "word_gt9": 0,
+    "prprn_num": 0,
+    "ast": 4,
+    "word_gt8": 0,
+    "whcl_num": 0,
+    "n_ratio": 0,
+    "d_num": 0,
+    "cjk_ratio": 0,
+    "p_len": 0,
+    "cl_type": 0,
+    "v_num": 2,
+    "n_ttr1": 0,
+    "x_type": 0,
+    "n_ttr2": 0,
+    "a_ttr": 1,
+    "atl": 2.5,
+    "n_ttr": 0,
+    "doc_strlen": 0,
+    "fitted_num": 0,
+    "c_len": 0,
+    "punct_err": 0,
+    "lemma_type": 7,
+    "atl_sd": 1.3093073,
+    "dirtyword": 0,
+    "v_type": 2,
+    "a_type": 2,
+    "v_ratio": 0.25,
+    "ptprtcl_num": 0,
+    "pinyin_ratio": 0.33333334,
+    "a_len": 3.5,
+    "ttr2": 6,
+    "c_ratio": 0,
+    "c_ttr": 0,
+    "r_len": 2.5,
+    "c_ttr1": 0,
+    "c_ttr2": 0,
+    "mwe_disconj": 0,
+    "para_first_sratio": 1,
+    "compcl_num": 0,
+    "para_token_avg": 8,
+    "h_num": 2,
+    "sc_num": 0,
+    "snt_tc_10_19": 0,
+    "token_type": 7,
+    "snt_tc_0_9": 0.952381,
+    "x_ttr1": 0,
+    "x_ttr2": 0,
+    "modifier_np": 0,
+    "mwe_pv_ratio": 0.125,
+    "dot_ratio": 0.24691357,
+    "r_ttr2": 2,
+    "r_ttr1": 1,
+    "r_ttr": 1,
+    "b0_num": 0,
+    "mwe_pronaux": 0,
+    "snt_tc_20_29": 0,
+    "fitted_ratio": 0,
+    "gramv_idf": 0,
+    "pinyin_num": 2,
+    "flesch_kincaid_grade_level": -0.26333427,
+    "spell_correct_ratio": 1,
+    "para_last_sratio": 0,
+    "r_ratio": 0.25,
+    "para_snt_avg": 2,
+    "ttr": 100,
+    "p_ttr": 0,
+    "pred_diff_max1": 2.5,
+    "pred_diff_max2": 2.4850001,
+    "relcl_num": 0,
+    "awl": 3,
+    "pred_diff_max3": 1.6566668,
+    "c_type": 0,
+    "content_word_ratio": 0,
+    "x_num": 0,
+    "x_ratio": 0,
+    "word_diff_num": 6,
+    "incomplete_num": 0,
+    "gramv_ratio": 0,
+    "n_len": 0,
+    "b1_bu": 0.16666669
+  },
+  "kw": {
+    "ready": 0.64798754,
+    "ok": 0.7616509
+  },
+  "info": {
+    "pingyu_key": "ttr1:1_b3:1_spell_correct_ratio:1",
+    "final_score": 36.20861,
+    "engine-version": "4.0.4017.220322",
+    "my_ip": "dsk.wrask.com",
+    "my_port": 7095,
+    "sntcmd_list": "NldpLat,WalkPre,SpellErr,WalkLat,FeedbackIssue",
+    "kpu_match": 0,
+    "pingyu": "文中拼写错误稍多，词汇表达贫乏。",
+    "cate_score_default": {
+      "1": 50.192593,
+      "2": 25.255447,
+      "3": 0,
+      "4": 90.466034
+    },
+    "finished": 3,
+    "rid": "10",
+    "pingyu_default": "文中拼写错误稍多，词汇表达贫乏。"
+  }}, did:str=None): 
+	''' to be filled into es, 2022.9.8 '''
+	import hashlib,en
+	if did is None : did  = hashlib.md5(json.dumps(dsk).encode("utf-8")).hexdigest()
+
+	actions = [] 
+	info = dsk.get('info',{})
+	actions.append( {"_id": did, "_source": dict(info, **{"type":"doc", "snts":[mkf.get('meta',{}).get('snt','') for mkf in dsk.get('snt',[])], 'score': round(float(dsk.get('info',{}).get("final_score",0)),2)}) } ) 
+	actions.append( {"_id": did +"-dim", "_source": dict(dsk.get('doc',{}), **{"type":"dim"} ) } ) 
+	actions.append( {"_id": did +"-kw", "_source": dict(dsk.get('kw',{}), **{"type":"kw"} ) } ) 
+
+	for i, mkf in enumerate(dsk.get('snt',[])):  
+		snt		= mkf.get('meta',{}).get('snt','')
+		doc		= spacy.nlp(snt) 
+		#cates = [ v['cate'][2:] for k,v in mkf.get('feedback',{}).items() if v['cate'].startswith("e_") or v['cate'].startswith("w_") ]
+		actions.append( {"_id": f"{did}-{i}", "_source": dict(dsk.get('kw',{}), **{"type":"kw"} ) } ) 
+		#[ actions.append( {"_id": f"{did}-{i}-fd-{v.get('ibeg',0)}", "_source": {"type":"feedback",'cate': v.get('cate',''), 'msg':v.get('short_msg',''), 'ibeg':v.get('ibeg',0)} ) for k,v in mkf.get('feedback',{}).items() if v['cate'].startswith("e_") or v['cate'].startswith("w_") ]
+		#	"chunks": [ {"start":sp.start, "end": sp.end,"type":"NP", "lem": doc[sp.end-1].lemma_, "text":sp.text} for sp in doc.noun_chunks ],
+		#for t in doc:		sntdic[sntkey][f'toks-{t.i}'] =  {'i':t.i, "head":t.head.i, 'lex':t.text, 'lem':t.lemma_, 'pos':t.pos_, 'tag':t.tag_, 'dep':t.dep_, "gpos":t.head.pos_, "glem":t.head.lemma_}
+	return actions
+
 if __name__ == "__main__":   #uvicorn.run(app, host='0.0.0.0', port=80)
 	#print ( es_keyness("VERB:.*", sepa=':'), flush=True) 
-	print ( snt_kps()) 
-	uvicorn.run(app, host='0.0.0.0', port=81)
\ No newline at end of file
+	print ( es_dsk())
\ No newline at end of file
